import UIKit



//: #### SwiftGenStoryboardEnumBuilder Usage Example

let enumBuilder = SwiftGenColorEnumBuilder()
if let colorsFile = NSBundle.mainBundle().pathForResource("colors", ofType: "txt") {
    try enumBuilder.parseTextFile(colorsFile)
}
print(enumBuilder.build())



//: #### Code Generated by the Builder

extension UIColor {
    private struct Cache {
        static var values = [String:UInt32]()
    }
    
    private static func parse(hexString: String) -> UInt32 {
        if let cached = Cache.values[hexString] {
            return cached
        }
        
        let scanner = NSScanner(string: hexString)
        let hasHash = scanner.scanString("#", intoString: nil)
        
        var value : UInt32 = 0
        scanner.scanHexInt(&value)
        
        let len = hexString.lengthOfBytesUsingEncoding(NSUTF8StringEncoding) - (hasHash ? 1 : 0)
        if len == 6 {
            // There were no alpha component, assume 0xff
            value = (value << 8) | 0xff
        }
        
        Cache.values[hexString] = value
        return value
    }
    
    convenience init(hexString: String) {
        let value = UIColor.parse(hexString)
        self.init(rgbaValue: value)
    }
    
    convenience init(rgbaValue: UInt32) {
        let red   = CGFloat((rgbaValue >> 24) & 0xff) / 255.0
        let green = CGFloat((rgbaValue >> 16) & 0xff) / 255.0
        let blue  = CGFloat((rgbaValue >>  8) & 0xff) / 255.0
        let alpha = CGFloat((rgbaValue      ) & 0xff) / 255.0
        
        self.init(red: red, green: green, blue: blue, alpha: alpha)
    }
}

extension UIColor {
    enum Name : UInt32 {
        case Translucent = 0xffffffcc
        case ArticleTitle = 0x33fe66ff
        case Cyan = 0xff66ccff
        case ArticleBody = 0x339666ff
    }
    
    convenience init(named name: Name) {
        self.init(rgbaValue: name.rawValue)
    }
}



//: #### Usage Example

UIColor(named: .ArticleTitle)
UIColor(named: .ArticleBody)
UIColor(named: .Translucent)
let orange = UIColor(hexString: "#ffcc88")
let lightGreen = UIColor(rgbaValue: 0x00ff88ff)

